@@ -14,10 +14,12 @@ __all__ = (
     "signals_blocked",
     "thread_worker",
     "WorkerBase",
+    "exceptions_as_dialog",
 )
 
 from ._code_syntax_highlight import CodeSyntaxHighlight
 from ._ensure_thread import ensure_main_thread, ensure_object_thread
+from ._errormsg_context import exceptions_as_dialog
 from ._message_handler import QMessageHandler
 from ._misc import signals_blocked
 from ._qthreading import (
